==> radiance-substance-extras-2.5.0-sources.jar: org/pushingpixels/substance/extras/api/painterpack/noise/CompoundNoiseFilter.java <==
/*
 * Copyright (c) 2005-2019 Radiance Kirill Grouchnikov. All Rights Reserved.
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 * 
 *  o Redistributions of source code must retain the above copyright notice, 
 *    this list of conditions and the following disclaimer. 
 *     
 *  o Redistributions in binary form must reproduce the above copyright notice, 
 *    this list of conditions and the following disclaimer in the documentation 
 *    and/or other materials provided with the distribution. 
 *     
 *  o Neither the name of the copyright holder nor the names of
 *    its contributors may be used to endorse or promote products derived 
 *    from this software without specific prior written permission. 
 *     
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, 
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR 
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR 
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, 
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, 
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; 
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE 
 * OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, 
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. 
 */
package org.pushingpixels.substance.extras.api.painterpack.noise;

import java.util.LinkedList;

/**
 * Compound noise filter that contains a chain of filters. This class is part of
 * officially supported API.
 * 
 * @author Kirill Grouchnikov
 */
public class CompoundNoiseFilter implements NoiseFilter {
	/**
	 * Filter chain.
	 */
	protected LinkedList<NoiseFilter> chain;

	/**
	 * Creates a new compound filter.
	 * 
	 * @param chain
	 *            Filter chain.
	 */
	public CompoundNoiseFilter(NoiseFilter... chain) {
		this.chain = new LinkedList<NoiseFilter>();
		for (NoiseFilter link : chain) {
			this.chain.add(link);
		}
	}

	@Override
	public double apply(double x, double y, double z, double origValue) {
		double val = origValue;
		for (NoiseFilter link : this.chain)
			val = link.apply(x, y, z, val);
		return val;
	}
}

==> radiance-substance-extras-3.0.0-sources.jar: org/pushingpixels/substance/extras/api/painterpack/noise/CompoundNoiseFilter.java <==
/*
 * Copyright (c) 2005-2020 Radiance Kirill Grouchnikov. All Rights Reserved.
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 * 
 *  o Redistributions of source code must retain the above copyright notice, 
 *    this list of conditions and the following disclaimer. 
 *     
 *  o Redistributions in binary form must reproduce the above copyright notice, 
 *    this list of conditions and the following disclaimer in the documentation 
 *    and/or other materials provided with the distribution. 
 *     
 *  o Neither the name of the copyright holder nor the names of
 *    its contributors may be used to endorse or promote products derived 
 *    from this software without specific prior written permission. 
 *     
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, 
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR 
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR 
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, 
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, 
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; 
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE 
 * OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, 
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. 
 */
package org.pushingpixels.substance.extras.api.painterpack.noise;

import java.util.LinkedList;

/**
 * Compound noise filter that contains a chain of filters. This class is part of
 * officially supported API.
 * 
 * @author Kirill Grouchnikov
 */
public class CompoundNoiseFilter implements NoiseFilter {
	/**
	 * Filter chain.
	 */
	protected LinkedList<NoiseFilter> chain;

	/**
	 * Creates a new compound filter.
	 * 
	 * @param chain
	 *            Filter chain.
	 */
	public CompoundNoiseFilter(NoiseFilter... chain) {
		this.chain = new LinkedList<>();
		for (NoiseFilter link : chain) {
			this.chain.add(link);
		}
	}

	@Override
	public double apply(double x, double y, double z, double origValue) {
		double val = origValue;
		for (NoiseFilter link : this.chain)
			val = link.apply(x, y, z, val);
		return val;
	}
}
